@@ -1,10 +1,14 @@
 # -*- coding: utf-8 -*-
-# $Id$
+# $Id: controlpanel.py 235454 2011-03-03 12:57:29Z mborch $
 """Collage site wide options"""
 
 from zope.component import adapts
 from zope.interface import implements
-from zope.app.schema.vocabulary import IVocabularyFactory
+try:
+    from zope.schema.interfaces import IVocabularyFactory
+except ImportError:
+    from zope.app.schema.vocabulary import IVocabularyFactory
+
 from zope.schema.vocabulary import SimpleVocabulary
 from zope.schema.vocabulary import SimpleTerm
 from zope.formlib.form import FormFields
@@ -21,16 +25,19 @@ from Products.Collage.config import COLLAGE_TYPES
 from Products.Collage.utilities import getPortal
 from Products.Collage.utilities import CollageMessageFactory as _
 
-
 class CollageSiteOptions(SchemaAdapterBase):
 
     implements(ICollageSiteOptions)
     adapts(IPloneSiteRoot)
 
+    ref_browser_empty = \
+        ProxyFieldProperty(ICollageSiteOptions['ref_browser_empty'])
+    ref_browser_types = \
+        ProxyFieldProperty(ICollageSiteOptions['ref_browser_types'])
     use_whitelist = ProxyFieldProperty(ICollageSiteOptions['use_whitelist'])
     types_whitelist = ProxyFieldProperty(ICollageSiteOptions['types_whitelist'])
     alias_whitelist = ProxyFieldProperty(ICollageSiteOptions['alias_whitelist'])
-    alias_search_limit = ProxyFieldProperty(ICollageSiteOptions['alias_search_limit'])
+    batch_size = ProxyFieldProperty(ICollageSiteOptions['batch_size'])
 
     def __init__(self, context):
         super(CollageSiteOptions, self).__init__(context)
@@ -51,16 +58,16 @@ class CollageSiteOptions(SchemaAdapterBase):
             return portal_type in self.alias_whitelist
         return True
 
-
 class CollageControlPanel(ControlPanelForm):
 
     form_fields = FormFields(ICollageSiteOptions)
     form_fields['types_whitelist'].custom_widget = MultiCheckBoxThreeColumnWidget
     form_fields['alias_whitelist'].custom_widget = MultiCheckBoxThreeColumnWidget
 
-    label = form_name = _(u'title_collage_controlpanel', default=u"Collage control panel")
-    description = _(u'help_collage_controlpanel', default=u"Site wide options for Collage")
-
+    label = form_name = _(u'title_collage_controlpanel',
+                          default=u"Collage control panel")
+    description = _(u'help_collage_controlpanel',
+                    default=u"Site wide options for Collage")
 
 class CollageUserFriendlyTypesVocabulary(object):
     """Vocabulary"""
@@ -77,4 +84,4 @@ class CollageUserFriendlyTypesVocabulary(object):
         items = [SimpleTerm(*v) for v in items]
         return SimpleVocabulary(items)
 
-CollageUserFriendlyTypesVocabularyFactory = CollageUserFriendlyTypesVocabulary()
\ No newline at end of file
+CollageUserFriendlyTypesVocabularyFactory = CollageUserFriendlyTypesVocabulary()
