@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# $Id: utilities.py 76587 2008-11-29 16:33:21Z glenfant $
+# $Id: utilities.py 82661 2009-03-18 07:33:10Z jensens $
 """Misc utilities"""
 
 import re
@@ -69,16 +69,11 @@ def getPortal():
 ###
 
 from zope.component import getAdapter
-ICollageSiteOptions = None
+from Products.Collage.interfaces import ICollageSiteOptions
 
 def getCollageSiteOptions():
     """Collage site options from contol panel"""
 
-    global ICollageSiteOptions
-
-    # Weird stuff for working around circular import
-    if ICollageSiteOptions is None:
-        from Products.Collage.interfaces import ICollageSiteOptions
     return getAdapter(getPortal(), ICollageSiteOptions)
 
 ###
